@@ -4,7 +4,7 @@
  * This file is part of pgFouine.
  * 
  * pgFouine - a PostgreSQL log analyzer
- * Copyright (c) 2005-2006 Guillaume Smet
+ * Copyright (c) 2005-2008 Guillaume Smet
  *
  * pgFouine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -157,8 +157,16 @@ class ReportAggregator {
 		return $formattedDuration;
 	}
 	
+	function shortenQueryText($queryText) {
+		if(CONFIG_MAX_QUERY_LENGTH > 0 && strlen($queryText) > CONFIG_MAX_QUERY_LENGTH) {
+			return substr($queryText, 0, CONFIG_MAX_QUERY_LENGTH).'...';
+		} else {
+			return $queryText;
+		}
+	}
+	
 	function formatRealQuery($query, $prepend = '', $append = '') {
-		return $prepend.$query->getText().$append;
+		return $prepend.$this->shortenQueryText($query->getText()).$append;
 	}
 	
 	function containsReportBlock($reportBlockName) {
