@@ -56,7 +56,7 @@ function usage($error = false) {
   -report [outputfile=]<block1,block2>   list of report blocks separated by a comma
                                          report blocks can be: overall, hourly, bytype, slowest, n-mosttime,
                                           n-mostfrequent, n-slowestaverage, history, n-mostfrequenterrors,
-                                          tsung
+                                          tsung, csv-query
                                          you can add several -report options if you want to generate several reports at once
   -examples <n>                          maximum number of examples for a normalized query
   -onlyselect                            ignore all queries but SELECT
@@ -67,10 +67,12 @@ function usage($error = false) {
   -user <user>                           consider only queries executed by this user
                                          (supports user1,user2 and /regexp/)
   -keepformatting                        keep the formatting of the query
+  -maxquerylength <length>               maximum length of a query: we cut it if it exceeds this length
   -durationunit <s|ms>                   unit used to display the durations. Default is s(econds).
   -title <title>                         define the title of the reports
   -syslogident <ident>                   PostgreSQL syslog identity. Default is postgres.
   -memorylimit <n>                       PHP memory limit in MB. Default is 512.
+  -quiet                                 quiet mode
   -debug                                 debug mode
   -profile                               profile mode
   -help                                  this help
@@ -215,6 +217,7 @@ $supportedReportBlocks = array(
 	'historyperpid' => 'QueriesHistoryPerPidReport',
 	'n-mostfrequenterrors' => 'NormalizedErrorsMostFrequentReport',
 	'tsung' => 'TsungSessionsReport',
+	'csv-query' => 'CsvQueriesHistoryReport'
 );
 $defaultReportBlocks = array('overall', 'bytype', 'n-mosttime', 'slowest', 'n-mostfrequent', 'n-slowestaverage');
 
@@ -364,6 +367,12 @@ if(isset($options['keepformatting'])) {
 	define('CONFIG_KEEP_FORMATTING', false);
 }
 
+if(isset($options['maxquerylength']) && is_numeric($options['maxquerylength'])) {
+	define('CONFIG_MAX_QUERY_LENGTH', $options['maxquerylength']);
+} else {
+	define('CONFIG_MAX_QUERY_LENGTH', 0);
+}
+
 if(isset($options['durationunit']) && $options['durationunit'] == 'ms') {
 	define('CONFIG_DURATION_UNIT', 'ms');
 } else {
@@ -410,6 +419,12 @@ if(isset($options['syslogident'])) {
 	define('CONFIG_SYSLOG_IDENTITY', 'postgres');
 }
 
+if(isset($options['quiet'])) {
+	define('CONFIG_QUIET', true);
+} else {
+	define('CONFIG_QUIET', false);
+}
+
 if($logtype == 'csvlog') {
 	$logReader = new CsvlogLogReader($filePath, $parser, 'PostgreSQLAccumulator');
 } else {
