@@ -11,10 +11,16 @@ define('PROFILE', false);
 define('CONFIG_ONLY_SELECT', false);
 define('CONFIG_TIMESTAMP_FILTER', false);
 define('CONFIG_DATABASE', false);
+define('CONFIG_DATABASE_LIST', false);
+define('CONFIG_DATABASE_REGEXP', false);
 define('CONFIG_USER', false);
+define('CONFIG_USER_LIST', false);
+define('CONFIG_USER_REGEXP', false);
 define('CONFIG_SYSLOG_IDENTITY', 'postgres');
 define('CONFIG_KEEP_FORMATTING', 1);
 
+ini_set('error_reporting', 2039);
+
 $stderr = fopen('php://stderr', 'w');
 
 $commonTests = &new GroupTest('Common tests');
